/* NAME:
** 	Poiss:OAFunctionValue
**
** 	COPYRIGHT 1993 BY ONYSCHUK AND ASSOCIATES
**	ALL RIGHTS RESERVED.
**
** REVISION HISTORY:
**	93.06.01	AA	starting point
**
**	93.07.20	MO	frantically made changes to support
**				the final feature set of OBJECT:Math 1.0.
**
** DESCRIPTION:
**	Return a Poisson random variable given an
**	i and a lambda.
*/

#import "Poiss.h"

#import "OAExceptions.h"


/* OTHER INCLUDES ****************************************/

#import <stdio.h>
#import <stdlib.h>

#import <math.h>


@implementation Poiss

/* SUPERCLASS METHODS ************************************/

- (const char **)arguments
{
    static char *a[3] = {
    	"i",
	"lambda",
	NULL
    }; 

    return a;
}


- evaluate
{
    id	iVal, lambdaVal;
    double factorial, i, lambda;

    iVal = [self valueForArgument:"i"];
    lambdaVal = [self valueForArgument:"lambda"];

    // if either iVal or lambdaVal can not be
    // expressed as an integer or double respectively,
    // an OA_badArgumentType exception will be raised
    // by the receiver.
    
    i = [iVal intValue];
    lambda = [lambdaVal doubleValue];
    
    // calculate the factorial only if 0 <= i <= 30
    // and raise a range exception if the value of
    // i falls outside.
    //
    // see the tutorial notes for pointers to more
    // efficient factorial calculations.
    
    factorial = 1;

    if ((i >= 0) && (i <= 30)) {
	int index;

	for (index = 1; index <= i; index ++) {
	    factorial = factorial * index;
	}
    }
    else {
	NX_RAISE(OA_badArgumentRange, self, iVal);
    }

#define E 2.7182818
    [self setDoubleValue:pow(E, -lambda) * (pow(lambda, i) / factorial)];
#undef E
    
    return self;
}

@end
