/* NAME:
**	OAExceptions.h
**
** 	COPYRIGHT 1992 BY ONYSCHUK AND ASSOCIATES
**	ALL RIGHTS RESERVED.
**
** REVISION HISTORY:
**	93.07.22	MO	Renamed old exception codes and moved them
**				to their own header file.
**
**	93.08.12	MO	Added code for undefined variable.
**
** DESCRIPTION:
**	OBJECT:Math exception codes.
*/

#import <appkit/errors.h>

enum OAExceptions
{
    /* COMPILE TIME ERRORS
    **
    ** To date, compile time errors are all trapped by the OACompiler
    ** object and not passed up the exception heirarchy. If either 
    ** of the following exceptions is encountered, OACompiler 
    ** returns nil from its -compile: and -compile:fromZone:
    ** methods
    */

    OA_notAFunction = NX_APPBASE,
    OA_notAnExpression,


    /* RUN TIME ERRORS
    **
    ** Always place your expression evaluations inside the NEXTSTEP
    ** exception handling macros NX_DURING...NX_HANDLER...NX_ENDHANDLER
    ** as any of the following expression exceptions may be raised
    ** during expression evaluation.
    **
    ** NOTE: the first argument passed through the exception handling
    ** mechanism is always the object raising the exception, while the
    ** second argument varies from exception to exception.
    */
    
    OA_tooManyArguments,
    
	/* DESCRIPTION:
	**	the user has provided too many arguments
	**	to a function causing some fatal
	**	confusion.
	**
	** ARGUMENT 2:
	**	the number of arguments expected by the function
	*/

    OA_tooFewArguments,
    
	/* DESCRIPTION:
	**	the user has provided too few arguments to
	**	a function causing some fatal confusion.
	**
	** ARGUMENT 2:
	**	the number of arguments expected by the function
	*/
	
    OA_badArgumentType,
    
    	/* DESCRIPTION:
	**	the user has provided an argument which is
	**	of the wrong type.
	**
	** ARGUMENT 2:
	**	the id of the offending argument.
	*/
	
    OA_badArgumentRange,
    
    	/* DESCRIPTION:
	**	the user has provided an argument who's type
	**	is correct but which falls outside of expected
	**	bounds.
	**
	** ARGUMENT 2:
	**	the id of the offending argument.
	*/
	
    OA_badArgumentFormat,
    
    	/* DESCRIPTION:
	**	the user has provided an argument who's type
	**	is correct but who's format is bad.
	**
	** ARGUMENT 2:
	**	the id of the offending argument.
	*/
	
    OA_divisionByZero,
    
    	/* DESCRIPTION:
	**	the user has provided arguments to a function
	**	which if evaluated would cause a division by
	**	zero to occur.
	**
	** ARGUMENT 2:
	**	the id of the offending subexpression
	**	(may be the same as ARGUMENT 1).
	*/
	
    OA_overflow,
    
    	/* DESCRIPTION:
	**	the user has provided arguments to a function
	**	which if evaluated would cause an overflow.
	**
	** ARGUMENT 2:
	**	NULL.
	*/

    OA_undefinedVariable
    
    	/* DESCRIPTION:
	**	the user has typed a variable name which isn't
	**	recognized by the variable retreival mechanism,
	**	or whose value hasn't been set.
	**
	** ARGUMENT 2:
	**	the id of the OAValue object used to hold 
	**	the variable name.
	*/
};
