/* NAME:
**	OAValue:Object
**
** 	COPYRIGHT 1992 BY ONYSCHUK AND ASSOCIATES
**	ALL RIGHTS RESERVED.
**
** REVISION HISTORY:
**	93.03.28	MO	starting point
**	93.08.10	MO	added code to support locating
**				OAValue in source text string,
**				and pointer back to the OAValue
**				parent.
**
** DESCRIPTION:
**	Abstract superclass representing all math system values.
*/

#import <objc/Object.h>
#import <dbkit/DBValue.h>

/* EXPORTED TYPES *******************************************************/

typedef enum _OATYPE {
    OA_nullType		= 0,
    OA_integerType	= 1,
    OA_floatType	= 2,
    OA_doubleType	= 4,
    OA_stringType	= 8,
    OA_objectType	= 16,
} OATYPE;


/* PROTOCOLS ************************************************************/

@protocol OAValues

- (int)intValue;
- setIntValue:(int)anInt;

- (float)floatValue;
- setFloatValue:(float)aFloat;

- (double)doubleValue;
- setDoubleValue:(double)aDouble;

- (const char *)stringValue;
- setStringValue:(const char *)aString;

- objectValue;
- setObjectValue:anObject;

- setNull;
- (BOOL)isNull;

- (OATYPE)type;
- (BOOL)filtersToType:(OATYPE)aType;

- (id <OAValues>)parent;
- setParent:(id <OAValues>)anObject;

- (unsigned)symbolOffset;
- setSymbolOffset:(unsigned)offset;

- (unsigned)symbolLength;
- setSymbolLength:(unsigned)length;

- evaluate;

@end

/* INTERFACE ************************************************************/

@interface OAValue:Object <OAValues>
{
@private
    id <OAValues>	 parent;
    unsigned int 	 offset, length;

    union _value
    {
    	id	 o;
	int	 i;
	float	 f;
	double	 d;
	char	*s;
    }			value;

    OATYPE		type;

    char		*buffer;    
}

/* INITIALIZING & FREEING OAVALUE VALUES ********************************/

- init;
- free;

/* READING & WRITING OAVALUES *******************************************/

- read:(NXTypedStream *)stream;
- write:(NXTypedStream *)stream;

@end
